@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 #
-# $Id: Mysql.pm,v 4.20 2006/03/18 15:00:44 matt Exp $
+# $Id: Mysql.pm, matt Exp $
 #
 
 package Mail::Toaster::Mysql;
@@ -15,7 +15,7 @@ use Params::Validate qw( :all );
 use English qw( -no_match_vars );
 
 use vars qw($VERSION $darwin $freebsd);
-$VERSION = '5.00';
+$VERSION = '5.04';
 
 use lib "lib";
 use Mail::Toaster::Perl    5; my $perl = Mail::Toaster::Perl->new;
@@ -400,9 +400,9 @@ sub install_darwin {
     };
 
     if ( -d "/usr/ports/dports" || "/usr/dports" || "/usr/darwinports" ) {
-        $darwin->port_install( port => "mysql4", debug=>$debug );
-        $darwin->port_install( port => "p5-dbi", debug=>$debug );
-        $darwin->port_install( port => "p5-dbd-mysql", debug=>$debug );
+        $darwin->port_install( port_name => "mysql4", debug=>$debug );
+        $darwin->port_install( port_name => "p5-dbi", debug=>$debug );
+        $darwin->port_install( port_name => "p5-dbd-mysql", debug=>$debug );
         return 1;
     }
 
@@ -555,7 +555,7 @@ sub phpmyadmin_install {
 
         print
 "NOTICE: the port install of phpmyadmin requires that Apache be installed in ports!\n";
-        $darwin->port_install( port => "phpmyadmin" );
+        $darwin->port_install( port_name => "phpmyadmin" );
         $dir = "/Library/Webserver/Documents/phpmyadmin";
     }
 
@@ -944,7 +944,7 @@ __END__
 
 =head1 NAME
 
-Mail::Toaster::Mysql
+Mail::Toaster::Mysql - so much more than just installing mysql
 
 head1 SYNOPSIS
 
