@@ -14,7 +14,7 @@ use Params::Validate qw( :all);
 
 use vars qw($VERSION $err);
 
-$VERSION = '5.02';
+$VERSION = '5.04';
 
 use lib "inc";
 use lib "lib";
@@ -363,8 +363,8 @@ sub perl_install {
             $self->module_load( module => "Mail::Toaster::Darwin" );
             my $darwin = Mail::Toaster::Darwin->new();
             
-            $darwin->port_install(port=>"perl5.8");
-            $darwin->port_install(port=>"p5-compress-zlib");
+            $darwin->port_install(port_name => "perl5.8" );
+            $darwin->port_install(port_name => "p5-compress-zlib" );
             return 1;
         }
 
@@ -469,11 +469,11 @@ __END__
 
 =head1 NAME
 
-Mail::Toaster::Perl
+Mail::Toaster::Perl - Perl specific functions for Mail Toaster
 
 =head1 SYNOPSIS
 
-Perl functions for working with perl and loading modules.
+Perl functions for loading, installing and testing perl modules.
 
 
 =head1 DESCRIPTION
